-- **************** DESCRIPTION OF PROGRAM **********************************
--
-- General purpose AM Watchdog
-- ---------------------------
-- This program acts as a watchdog for various external (non-TDC)
-- applications that write to the LCN, such as an OPC client
-- or PHD
-- 
--
-- Usage
-- -----
-- Build an AM Numeric point and an AM Flag point
--
-- Compile the AMNN and AMFLAG parameter lists. Alternatively, if you
-- already have compatible parameter lists, just change the code below
-- to suit.
--
-- Compile this package - this should create the CDS and AM object code.
--
-- Build an AM Custom point using this package, referencing the AM Numeric
-- and Flag points that you have just built.
--
-- The scan time (period) of the point will depend on the rate at which
-- the remote application can update the LCN.
--
-- Link the CL block (via the package) to the AM Custom point.
--
-- The remote application needs to write, on a regular basis, to the AM
-- Numeric point specified in the WATCHDOG parameter of the CDS.
-- Importantly, the value that it writes must change.
-- 
-- If the value is the same on two successive scans, an alarm is raised
-- using the Flag point referenced by the AlmFlag parameter.
--
-- ***************************************************************************
--
-- Revision        Date          By                    Revision Details 
--
-- 0.00            31/03/05      Chris Deverill        Original Version
  
-- ***************************************************************************
  
-------
Package 
-------
  
  
Custom
 
        PARAMETER Watchdog : AMNN
                  "Written by remote system"
                  ACCESS Engineer

 
        PARAMETER LastVal  : Number
                  "Previous Value of Watchdog"
                  value -1
                  ACCESS Engineer 
  
        PARAMETER AlmFlag  : AMFLAG
                  "Alarm Flag"
                  ACCESS Engineer

End Custom

   
------------------------------------
Block CheckVal (Generic; at General)
------------------------------------
%Relax Linker_SDE_Checks 
    
    if badval(Watchdog.PV) then
&       set AlmFlag.PV = $ord1
    else if (Watchdog.PV = LastVal) then
&       set AlmFlag.PV = $ord1
    else
&      (set LastVal = Watchdog.PV;
&       set AlmFlag.PV = $ord0)


End CheckVal



-----------  
End Package 
-----------  

